import { Prop, Event, Component, Host, h } from '@stencil/core';
export class FtlBuckle {
  constructor() {
    this.opacity = '1';
    this.showGrid = true;
    this.activeToggle = 'figma';
    this.view = 'toggle';
    this.mode = 'side';
  }
  _emitOnChange(attribute, value) {
    this.ftlOnChange.emit({
      attribute,
      value
    });
  }
  _updateShowGrid(val) {
    this.showGrid = val;
    this._emitOnChange('show-grid', val);
  }
  _updateView(e) {
    const target = e.target;
    const value = target.value;
    this.view = value;
    this._emitOnChange('view', value);
  }
  _updateOpacity(opacity) {
    this.opacity = opacity;
    this._emitOnChange('opacity', opacity);
  }
  _updateActiveToggle(e) {
    let val = 'figma';
    if (e.target.checked) {
      val = 'code';
    }
    this.activeToggle = val;
    this._emitOnChange('active-toggle', val);
  }
  get control() {
    return (h("ul", { class: "segmented-control" },
      h("li", { class: "segmented-control__item" },
        h("input", { class: "segmented-control__input", type: "radio", value: "figma", name: "option", id: "option-figma", checked: this.activeToggle === 'figma', onChange: (e) => this._updateActiveToggle(e) }),
        h("label", { class: "segmented-control__label", htmlFor: "option-figma" }, "Figma")),
      h("li", { class: "segmented-control__item" },
        h("input", { class: "segmented-control__input", type: "radio", value: "code", name: "option", id: "option-code", checked: this.activeToggle === 'code', onChange: (e) => this._updateActiveToggle(e) }),
        h("label", { class: "segmented-control__label", htmlFor: "option-code" }, "Code"))));
  }
  get viewControl() {
    return (h("ul", { class: "segmented-control" },
      h("li", { class: "segmented-control__item" },
        h("input", { class: "segmented-control__input", type: "radio", value: "toggle", name: "option", id: "option-toggle", checked: this.view === 'toggle', onChange: (e) => this._updateView(e) }),
        h("label", { class: "segmented-control__label", htmlFor: "option-toggle" }, "Toggle")),
      h("li", { class: "segmented-control__item" },
        h("input", { class: "segmented-control__input", type: "radio", value: "overlay", name: "option", id: "option-overlay", checked: this.view === 'overlay', onChange: (e) => this._updateView(e) }),
        h("label", { class: "segmented-control__label", htmlFor: "option-overlay" }, "Overlay")),
      h("li", { class: "segmented-control__item" },
        h("input", { class: "segmented-control__input", type: "radio", value: "sidebyside", name: "option", id: "option-sidebyside", checked: this.view === 'side-by-side', onChange: (e) => this._updateView(e) }),
        h("label", { class: "segmented-control__label", htmlFor: "option-sidebyside" }, "Side By Side"))));
  }
  get selects() {
    return (
    //@ts-ignore
    h("select", { name: "mode", id: "mode", class: "select-mode", onChange: (e) => this._updateView(e.target.value) },
      h("option", { value: "toggle", selected: this.view === 'toggle' }, "Toggle"),
      h("option", { value: "overlay", selected: this.view === 'overlay' }, "Overlay"),
      h("option", { value: "side-by-side", selected: this.view === 'side-by-side' }, "SIde By Side")));
  }
  render() {
    return (h(Host, null,
      h("div", { class: "controls-bar", part: "base" },
        h("div", { part: "holster-option" }, this.viewControl),
        this.view === 'overlay' ? (h("div", { part: "holster-option", class: "control opacity-control" },
          h("label", { htmlFor: "slider" }, "Opacity:"),
          h("input", { type: "range", id: "slider", min: "0.0", max: "1.0", step: "0.1", class: "opacity-slider", name: "slider", onInput: (e) => this._updateOpacity(e.target.value), value: this.opacity }))) : null,
        this.view === 'toggle' ? (h("div", { part: "holster-option" },
          h("div", { class: "switch" },
            h("span", null, "Figma"),
            h("input", { onInput: (e) => this._updateActiveToggle(e), checked: this.activeToggle === 'code', type: "checkbox", id: "switch" }),
            h("label", { htmlFor: "switch" }, "Toggle"),
            h("span", null, "Code")))) : null,
        h("div", { part: "holster-option" },
          h("label", { htmlFor: "showGrid", class: "checkbox checkbox--showGrid" },
            h("input", { class: "checkbox__input", id: "showGrid", type: "checkbox", checked: this.showGrid, onChange: (e) => this._updateShowGrid(e.target.checked) }),
            "Show Grid")))));
  }
  static get is() { return "ftl-buckle"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["ftl-buckle.css"]
  }; }
  static get styleUrls() { return {
    "$": ["ftl-buckle.css"]
  }; }
  static get properties() { return {
    "opacity": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "opacity",
      "reflect": true,
      "defaultValue": "'1'"
    },
    "showGrid": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "show-grid",
      "reflect": false,
      "defaultValue": "true"
    },
    "activeToggle": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "active-toggle",
      "reflect": false,
      "defaultValue": "'figma'"
    },
    "view": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "viewOptions",
        "resolved": "\"overlay\" | \"side-by-side\" | \"toggle\"",
        "references": {
          "viewOptions": {
            "location": "local"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "view",
      "reflect": false,
      "defaultValue": "'toggle'"
    },
    "mode": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "mode",
      "reflect": false,
      "defaultValue": "'side'"
    }
  }; }
  static get events() { return [{
      "method": "ftlOnChange",
      "name": "ftl-on-change",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "configSettings",
        "resolved": "{ attribute: \"view\" | \"show-grid\" | \"active-toggle\" | \"opacity\"; value: string; }",
        "references": {
          "configSettings": {
            "location": "local"
          }
        }
      }
    }]; }
}
